//
//  DrinkDetailView.swift
//  Drink
//
//  Create with Swift
//  Tutorial - Using TipKit on a SwiftUI app
//  https://www.createwithswift.com/using-tipkit-on-a-swiftui-app
//

import SwiftUI

struct DrinkDetailView: View {
    @Environment(DrinkStore.self) var drinkViewModel: DrinkStore
    
    @State var drink: Drink
    @State var isFavorite: Bool = false
    
    var body: some View {
        
        VStack {
            ZStack {
                RoundedRectangle(cornerRadius: 25)
                    .foregroundStyle(.ultraThickMaterial)
                    .frame(width: 300, height: 300)
                VStack{
                    Image(systemName: drink.imageName)
                        .font(.largeTitle)
                        .foregroundStyle(.brown)
                    Text(drink.name)
                        .font(.title)
                }
            }
        }
        .onAppear {
            isFavorite = drink.isFavorite
        }
        .toolbar{
            ToolbarItem {
                Button {
                    drinkViewModel
                        .updateFavoriteStatus(for: drink)
                    isFavorite.toggle()
                } label: {
                    Image(systemName: isFavorite ? "star.fill" : "star")
                        .foregroundColor(isFavorite ? .yellow : .gray)
                }
            }
        }
    }
    
}

#Preview {
    NavigationStack {
        DrinkDetailView(drink: Drink(name: "Coffee", imageName: "cup.and.saucer.fill", isFavorite: true))
            .environment(DrinkStore())
    }
}
